@@ -13,7 +13,8 @@ def log():
     click.echo('log')
 
 @main.command()
-def read():
-    clazz = DSMRReader()
+@click.option('-d', '--debug', is_flag=True)
+def read(debug):
+    clazz = DSMRReader(debug=debug)
 
     clazz.read()
\ No newline at end of file
