@@ -41,13 +41,11 @@ class DSMREntity(object):
 
     try:
       value = round(float(value), 2)
+
     except TypeError:
       pass
 
-    if value is not None:
-      return value
-
-    return None
+    return value
 
   @property
   def unit_of_measurement(self):
@@ -235,29 +233,37 @@ class DSMRReader():
           if self.debug:
             print('>> Reading DSMR in debug mode') 
 
-          for telegram in self.serial_reader.read():
+          for telegram in self.serial_reader.read_as_object():
+            os.system('clear')
 
-            if (self.debug):
-              print(telegram)
+            # [attr for attr, value in telegram]
 
-            self.__update_entities_telegram(telegram)
+            print(telegram)
+            
 
-            data = dict()
+          # for telegram in self.serial_reader.read():
 
-            for device in self.devices:
-                if device.unit_of_measurement == 'kW':
-                    value = float(device.state()) * 1000
-                else:
-                    value = device.state()
+          #   if (self.debug):
+          #     print(telegram)
 
-                # print(f'{device.name} == {value} {device.unit_of_measurement or ""}')
+          #   self.__update_entities_telegram(telegram)
 
-                data[device.name] = value
+          #   data = dict()
 
-            print(json.dumps(data, indent=2))
+          #   for device in self.devices:
+          #       if device.unit_of_measurement == 'kW':
+          #           value = float(device.state()) * 1000
+          #       else:
+          #           value = device.state()
+
+          #       # print(f'{device.name} == {value} {device.unit_of_measurement or ""}')
+
+          #       data[device.name] = value
+
+          #   print(json.dumps(data, indent=2))
 
 
-            print('=' * 80)
+          #   print('=' * 80)
 
         except Exception as e:
           print(str(e))
